@@ -6,21 +6,31 @@
 /*
  * Copyright (c) 2007-2015 The OpenRC Authors.
  * See the Authors file at the top-level directory of this distribution and
- * https://github.com/OpenRC/openrc/blob/master/AUTHORS
+ * https://github.com/OpenRC/openrc/blob/HEAD/AUTHORS
  *
  * This file is part of OpenRC. It is subject to the license terms in
  * the LICENSE file found in the top-level directory of this
- * distribution and at https://github.com/OpenRC/openrc/blob/master/LICENSE
+ * distribution and at https://github.com/OpenRC/openrc/blob/HEAD/LICENSE
  * This file may not be copied, modified, propagated, or distributed
  *    except according to the terms contained in the LICENSE file.
  */
 
 #include <fnmatch.h>
+#include <ctype.h>
+#include <dirent.h>
+#include <errno.h>
+#include <limits.h>
+#include <stdbool.h>
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <strings.h>
+#include <sys/stat.h>
 
 #include "queue.h"
 #include "librc.h"
 #include "helpers.h"
+#include "misc.h"
 
 bool
 rc_yesno(const char *value)
@@ -117,7 +127,7 @@ rc_getline(char **line, size_t *len, FILE *fp)
 }
 
 char *
-rc_proc_getent(const char *ent _unused)
+rc_proc_getent(const char *ent RC_UNUSED)
 {
 #ifdef __linux__
 	FILE *fp;
@@ -186,7 +196,7 @@ rc_config_list(const char *file)
 		if (token && (strlen(token) > 1)) {
 			/* If not variable assignment then skip */
 			if (strchr(token, '=')) {
-				/* Stip the newline if present */
+				/* Strip the newline if present */
 				if (token[strlen(token) - 1] == '\n')
 					token[strlen(token) - 1] = 0;
 
@@ -210,11 +220,11 @@ static void rc_config_set_value(RC_STRINGLIST *config, char *value)
 	bool replaced;
 	char *token;
 
-	if (! p)
+	if (!p)
 		return;
 	if (strncmp(p, "export ", 7) == 0)
 		p += 7;
-	if (! (token = strsep(&p, "=")))
+	if (!(token = strsep(&p, "=")))
 		return;
 
 	entry = xstrdup(token);
@@ -338,7 +348,7 @@ static RC_STRINGLIST * rc_config_directory(RC_STRINGLIST *config)
 		if (rc_conf_d_files) {
 			rc_stringlist_sort(&rc_conf_d_files);
 			TAILQ_FOREACH(fname, rc_conf_d_files, entries) {
-				if (! fname->value)
+				if (!fname->value)
 					continue;
 				sprintf(path, "%s/%s", RC_CONF_D, fname->value);
 				rc_conf_d_list = rc_config_list(path);
@@ -405,7 +415,7 @@ rc_conf_value(const char *setting)
 	RC_STRING *s;
 	char *p;
 
-	if (! rc_conf) {
+	if (!rc_conf) {
 		rc_conf = rc_config_load(RC_CONF);
 		atexit(_free_rc_conf);
 
@@ -413,7 +423,7 @@ rc_conf_value(const char *setting)
 		if (exists(RC_CONF_OLD)) {
 			old = rc_config_load(RC_CONF_OLD);
 			TAILQ_CONCAT(rc_conf, old, entries);
-			free(old);
+			rc_stringlist_free(old);
 		}
 
 		rc_conf = rc_config_directory(rc_conf);
