@@ -20,26 +20,21 @@
  *    except according to the terms contained in the LICENSE file.
  */
 
-#include <sys/types.h>
-#include <sys/ioctl.h>
-#include <sys/param.h>
-#include <sys/stat.h>
-#include <sys/utsname.h>
-#include <sys/wait.h>
-
 #include <errno.h>
 #include <dirent.h>
-#include <ctype.h>
 #include <getopt.h>
 #include <libgen.h>
-#include <limits.h>
 #include <pwd.h>
 #include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
 #include <string.h>
-#include <strings.h>
+#include <sys/ioctl.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <sys/utsname.h>
+#include <sys/wait.h>
 #include <termios.h>
 #include <unistd.h>
 
@@ -49,9 +44,9 @@
 #include "rc-logger.h"
 #include "misc.h"
 #include "plugin.h"
-
 #include "version.h"
 #include "_usage.h"
+#include "helpers.h"
 
 const char *extraopts = NULL;
 const char getoptstring[] = "a:no:s:S" getoptstring_COMMON;
@@ -382,7 +377,7 @@ static void
 handle_signal(int sig)
 {
 	int serrno = errno;
-	char *signame = NULL;
+	const char *signame = NULL;
 	pid_t pid;
 	RC_PID *pi;
 	int status = 0;
@@ -414,15 +409,15 @@ handle_signal(int sig)
 
 	case SIGINT:
 		if (!signame)
-			xasprintf(&signame, "SIGINT");
+			signame = "SIGINT";
 		/* FALLTHROUGH */
 	case SIGTERM:
 		if (!signame)
-			xasprintf(&signame, "SIGTERM");
+			signame = "SIGTERM";
 		/* FALLTHROUGH */
 	case SIGQUIT:
 		if (!signame)
-			xasprintf(&signame, "SIGQUIT");
+			signame = "SIGQUIT";
 		eerrorx("%s: caught %s, aborting", applet, signame);
 		/* NOTREACHED */
 	case SIGUSR1:
@@ -452,7 +447,7 @@ handle_signal(int sig)
 }
 
 static void
-do_sysinit()
+do_sysinit(void)
 {
 	struct utsname uts;
 	const char *sys;
@@ -505,7 +500,6 @@ runlevel_config(const char *service, const char *level)
 	char *conf, *dir;
 	bool retval;
 
-	dir = dirname(init);
 	dir = dirname(init);
 	xasprintf(&conf, "%s/conf.d/%s.%s", dir, service, level);
 	retval = exists(conf);
@@ -696,7 +690,7 @@ do_start_services(const RC_STRINGLIST *start_services, bool parallel)
 }
 
 #ifdef RC_DEBUG
-static void
+RC_NORETURN static void
 handle_bad_signal(int sig)
 {
 	char pid[10];
