@@ -26,47 +26,44 @@
 # define _GNU_SOURCE
 #endif
 
-#include <sys/types.h>
-#include <sys/ioctl.h>
-#include <sys/resource.h>
-#include <sys/stat.h>
-#include <termios.h>
-#include <sys/time.h>
-#include <sys/wait.h>
-
-#ifdef __linux__
-#include <sys/syscall.h> /* For io priority */
-#include <sys/prctl.h> /* For prctl */
-#endif
-
-#include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <getopt.h>
 #include <limits.h>
 #include <grp.h>
 #include <pwd.h>
+#include <sched.h>
 #include <signal.h>
+#include <stdbool.h>
 #include <stddef.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/ioctl.h>
+#include <sys/resource.h>
+#include <sys/stat.h>
+#include <sys/time.h>
+#include <sys/types.h>
+#include <sys/wait.h>
+#ifdef __linux__
+# include <sys/syscall.h> /* For io priority */
+# include <sys/prctl.h> /* For prctl */
+#endif
+#include <termios.h>
 #include <time.h>
 #include <unistd.h>
 
 #ifdef HAVE_PAM
-#include <security/pam_appl.h>
+# include <security/pam_appl.h>
 
 /* We are not supporting authentication conversations */
 static struct pam_conv conv = { NULL, NULL};
 #endif
 
 #ifdef HAVE_CAP
-#include <sys/capability.h>
+# include <sys/capability.h>
 #endif
 
-#include <sched.h>
-
 #include "einfo.h"
 #include "queue.h"
 #include "rc.h"
@@ -182,9 +179,9 @@ extern char **environ;
 # define SYS_ioprio_set __NR_ioprio_set
 #endif
 #if !defined(__DragonFly__)
-static inline int ioprio_set(int which _unused,
-			     int who _unused,
-			     int ioprio _unused)
+static inline int ioprio_set(int which RC_UNUSED,
+			     int who RC_UNUSED,
+			     int ioprio RC_UNUSED)
 {
 #ifdef SYS_ioprio_set
 	return syscall(SYS_ioprio_set, which, who, ioprio);
@@ -207,20 +204,20 @@ handle_signal(int sig)
 {
 	int status;
 	int serrno = errno;
-	char *signame = NULL;
+	const char *signame = NULL;
 
 	switch (sig) {
 	case SIGINT:
 		if (!signame)
-			xasprintf(&signame, "SIGINT");
+			signame = "SIGINT";
 		/* FALLTHROUGH */
 	case SIGTERM:
 		if (!signame)
-			xasprintf(&signame, "SIGTERM");
+			signame = "SIGTERM";
 		/* FALLTHROUGH */
 	case SIGQUIT:
 		if (!signame)
-			xasprintf(&signame, "SIGQUIT");
+			signame = "SIGQUIT";
 		eerrorx("%s: caught %s, aborting", applet, signame);
 		/* NOTREACHED */
 
@@ -239,9 +236,6 @@ handle_signal(int sig)
 		eerror("%s: caught unknown signal %d", applet, sig);
 	}
 
-	/* free signame */
-	free(signame);
-
 	/* Restore errno */
 	errno = serrno;
 }
@@ -1104,9 +1098,12 @@ int main(int argc, char **argv)
 				|| rc_yesno(getenv("EINFO_QUIET")))
 			dup2(stderr_fd, STDERR_FILENO);
 
+#ifdef HAVE_CLOSEFROM
+		closefrom(3);
+#else
 		for (i = getdtablesize() - 1; i >= 3; --i)
-			if (i != pipefd[1])
-				close(i);
+			close(i);
+#endif
 
 		if (scheduler != NULL) {
 			int scheduler_index;
