@@ -22,20 +22,11 @@
 #define ONE_SECOND    1000000000
 #define ONE_MS           1000000
 
-#include <sys/types.h>
-#include <sys/ioctl.h>
-#include <sys/resource.h>
-#include <sys/stat.h>
-#include <termios.h>
-#include <sys/time.h>
-#include <sys/wait.h>
-
-#ifdef __linux__
-#include <sys/syscall.h> /* For io priority */
-#include <sys/prctl.h> /* For prctl */
+#ifdef HAVE_CLOSE_RANGE_CLOEXEC
+/* For close_range() */
+# define _GNU_SOURCE
 #endif
 
-#include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <getopt.h>
@@ -47,7 +38,17 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <stdbool.h>
+#include <strings.h>
+#ifdef __linux__
+# include <sys/syscall.h> /* For io priority */
+# include <sys/prctl.h> /* For prctl */
+#endif
 #include <syslog.h>
+#include <sys/ioctl.h>
+#include <sys/resource.h>
+#include <sys/stat.h>
+#include <sys/wait.h>
 #include <time.h>
 #include <unistd.h>
 
@@ -191,8 +192,8 @@ extern char **environ;
 # define SYS_ioprio_set __NR_ioprio_set
 #endif
 #if !defined(__DragonFly__)
-static inline int ioprio_set(int which _unused, int who _unused,
-			     int ioprio _unused)
+static inline int ioprio_set(int which RC_UNUSED, int who RC_UNUSED,
+			     int ioprio RC_UNUSED)
 {
 #ifdef SYS_ioprio_set
 	return syscall(SYS_ioprio_set, which, who, ioprio);
@@ -207,7 +208,7 @@ static void cleanup(void)
 	free(changeuser);
 }
 
-static void re_exec_supervisor(void)
+RC_NORETURN static void re_exec_supervisor(void)
 {
 	syslog(LOG_WARNING, "Re-executing for %s", svcname);
 	execlp("supervise-daemon", "supervise-daemon", svcname, "--reexec",
@@ -353,7 +354,7 @@ static pid_t exec_command(const char *cmd)
 	return pid;
 }
 
-static void child_process(char *exec, char **argv)
+RC_NORETURN static void child_process(char *exec, char **argv)
 {
 	RC_STRINGLIST *env_list;
 	RC_STRING *env;
@@ -569,8 +570,11 @@ static void child_process(char *exec, char **argv)
 	if (redirect_stderr || rc_yesno(getenv("EINFO_QUIET")))
 		dup2(stderr_fd, STDERR_FILENO);
 
-	for (i = getdtablesize() - 1; i >= 3; --i)
-		fcntl(i, F_SETFD, FD_CLOEXEC);
+#ifdef HAVE_CLOSE_RANGE_CLOEXEC
+	if (close_range(3, UINT_MAX, CLOSE_RANGE_CLOEXEC) < 0)
+#endif
+		for (i = getdtablesize() - 1; i >= 3; --i)
+			fcntl(i, F_SETFD, FD_CLOEXEC);
 	cmdline = make_cmdline(argv);
 	syslog(LOG_INFO, "Child command line: %s", cmdline);
 	free(cmdline);
@@ -583,7 +587,7 @@ static void child_process(char *exec, char **argv)
 	eerrorx("%s: failed to exec `%s': %s", applet, exec,strerror(errno));
 }
 
-static void supervisor(char *exec, char **argv)
+RC_NORETURN static void supervisor(char *exec, char **argv)
 {
 	FILE *fp;
 	char buf[2048];
